fedwire20022

package module
v0.3.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 6, 2026 License: Apache-2.0 Imports: 0 Imported by: 0

README

Moov Banner Logo

Community · Blog

GoDoc Build Status Coverage Status Go Report Card Repo Size Apache 2 License Slack Channel GitHub Stars Twitter

moov-io/fedwire20022

Moov's mission is to give developers an easy way to create and integrate bank processing into their own software products. Our open source projects are each focused on solving a single responsibility in financial services and designed around performance, scalability, and ease of use.

This repository contains a subset of ISO 20022 messages for FedWire payments. ISO 20022 is a standard for electronic data interchange between financial institutions. It describes a metadata repository containing descriptions of messages and business processes, and a maintenance process for the repository content. The standard covers financial information transferred between financial institutions that includes payment transactions, securities trading and settlement information, credit and debit card transactions, and other financial information.

Project Status

Go code is generated with xsdgen inside the gen/ folder. Please star the project if you are interested in its progress. Feedback on this early version of ISO 20022 is appreciated and vital to its success. Please let us know if you encounter any bugs/unclear documentation or have feature suggestions by opening up an issue. Thanks!

Naming Conventions

The XSDs define some naming that can be confusing.

Go Package Description
gen/fedwirefunds_incoming Messages sent INTO the Fed Wire service - from a bank or vendor.
gen/fedwirefunds_outgoing Messages coming INTO a bank or vendor - from the Fed Wire service.

Usage

Go Library

This project offers Go structures which can read and write XML encoded ISO 20022 messages. Go has several known limitations around XML namespace prefixes which are required for FedWire messages. Encoding messages can include namespace prefixes (xml:"ns:Name") but decoding messages cannot (xml:"Name").

Getting Help

channel info
Twitter @moov You can follow Moov.io's Twitter feed to get updates on our project(s). You can also tweet us questions or just share blogs or stories.
GitHub Issue If you are able to reproduce a problem please open a GitHub Issue under the specific project that caused the error.
moov-io slack Join our slack channel (#fedwire) to have an interactive discussion about the development of the project.

Supported and Tested Platforms

  • 64-bit Linux (Ubuntu, Debian), macOS, and Windows

License

Apache License 2.0 - See LICENSE for details.

Documentation

Overview

Package fedwire20022 is a collection of generated Go files from ISO 20022 messages.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Document

type Document interface{}

Directories

Path Synopsis
gen
admi_002_001_01
Code generated by GoComply XSD2Go for Moov; DO NOT EDIT.
Code generated by GoComply XSD2Go for Moov; DO NOT EDIT.
admi_004_001_02
Code generated by GoComply XSD2Go for Moov; DO NOT EDIT.
Code generated by GoComply XSD2Go for Moov; DO NOT EDIT.
admi_006_001_01
Code generated by GoComply XSD2Go for Moov; DO NOT EDIT.
Code generated by GoComply XSD2Go for Moov; DO NOT EDIT.
admi_007_001_01
Code generated by GoComply XSD2Go for Moov; DO NOT EDIT.
Code generated by GoComply XSD2Go for Moov; DO NOT EDIT.
admi_011_001_01
Code generated by GoComply XSD2Go for Moov; DO NOT EDIT.
Code generated by GoComply XSD2Go for Moov; DO NOT EDIT.
camt_029_001_09
Code generated by GoComply XSD2Go for Moov; DO NOT EDIT.
Code generated by GoComply XSD2Go for Moov; DO NOT EDIT.
camt_052_001_08
Code generated by GoComply XSD2Go for Moov; DO NOT EDIT.
Code generated by GoComply XSD2Go for Moov; DO NOT EDIT.
camt_056_001_08
Code generated by GoComply XSD2Go for Moov; DO NOT EDIT.
Code generated by GoComply XSD2Go for Moov; DO NOT EDIT.
camt_060_001_05
Code generated by GoComply XSD2Go for Moov; DO NOT EDIT.
Code generated by GoComply XSD2Go for Moov; DO NOT EDIT.
camt_110_001_01
Code generated by GoComply XSD2Go for Moov; DO NOT EDIT.
Code generated by GoComply XSD2Go for Moov; DO NOT EDIT.
camt_111_001_01
Code generated by GoComply XSD2Go for Moov; DO NOT EDIT.
Code generated by GoComply XSD2Go for Moov; DO NOT EDIT.
fedwirefunds_incoming
Code generated by GoComply XSD2Go for Moov; DO NOT EDIT.
Code generated by GoComply XSD2Go for Moov; DO NOT EDIT.
fedwirefunds_outgoing
Code generated by GoComply XSD2Go for Moov; DO NOT EDIT.
Code generated by GoComply XSD2Go for Moov; DO NOT EDIT.
head_001_001_03
Code generated by GoComply XSD2Go for Moov; DO NOT EDIT.
Code generated by GoComply XSD2Go for Moov; DO NOT EDIT.
pacs_002_001_10
Code generated by GoComply XSD2Go for Moov; DO NOT EDIT.
Code generated by GoComply XSD2Go for Moov; DO NOT EDIT.
pacs_004_001_10
Code generated by GoComply XSD2Go for Moov; DO NOT EDIT.
Code generated by GoComply XSD2Go for Moov; DO NOT EDIT.
pacs_008_001_08
Code generated by GoComply XSD2Go for Moov; DO NOT EDIT.
Code generated by GoComply XSD2Go for Moov; DO NOT EDIT.
pacs_009_001_08
Code generated by GoComply XSD2Go for Moov; DO NOT EDIT.
Code generated by GoComply XSD2Go for Moov; DO NOT EDIT.
pacs_028_001_03
Code generated by GoComply XSD2Go for Moov; DO NOT EDIT.
Code generated by GoComply XSD2Go for Moov; DO NOT EDIT.
pain_013_001_07
Code generated by GoComply XSD2Go for Moov; DO NOT EDIT.
Code generated by GoComply XSD2Go for Moov; DO NOT EDIT.
pain_014_001_07
Code generated by GoComply XSD2Go for Moov; DO NOT EDIT.
Code generated by GoComply XSD2Go for Moov; DO NOT EDIT.
xmldsig
Code generated by GoComply XSD2Go for Moov; DO NOT EDIT.
Code generated by GoComply XSD2Go for Moov; DO NOT EDIT.
pkg

Jump to